# Установка

В файл `composer.json` добавить

    "repositories": {
        "gitlab.iwayex.com/45": {
            "type": "composer",
            "url": "https://gitlab.iwayex.com/api/v4/group/45/-/packages/composer/packages.json"
        }
    }

Выполнить команду `composer require iwaydev/localization-client`

В файле конфигов `app.php`, в секцию `'providers'` добавить провайдер

    Iwaydev\Localization\LocalizationServiceProvider::class

Опубликовать конфиг

    make artis q="vendor:publish --provider=\"Iwaydev\Localization\LocalizationServiceProvider\" --tag=config --force"

В файле `dev.stack.yml` для конейнера `php` в `extra_hosts` нужно добавить хосты:

    extra_hosts:
      - "api.localization.local:{{IP_ADDRESS}}"

# Настройка

В `.env` файлы для каждого стейджа прописываем переменные окружения:

    LOCALIZATION_URL=http://api.localization.local:125
    LOCALIZATION_API_VERSION=v1
    LOCALIZATION_CACHE_CLIENT_LIFETIME=3600
    LOCALIZATION_CACHE_SERVICE_LIFETIME=1814400
    LOCALIZATION_PROJECT_SLUG=bizontrip
    LOCALIZATION_PASSWORD=idu183

Где:

- `LOCALIZATION_URL` - URL апи сервиса переводов
- `LOCALIZATION_VERSION` - версия используемого апи
- `LOCALIZATION_CACHE_CLIENT_LIFETIME` - время, в секундах, на которое будут кэшироваться ответы клиента
- `LOCALIZATION_CACHE_SERVICE_LIFETIME` - время, в секундах, на которое будут кэшироваться переводы и хэш проекта
- `LOCALIZATION_PROJECT_SLUG` - slug, строковый идентификатор, проекта. Используется в качестве логина
- `LOCALIZATION_PASSWORD` - пароль проекта


Если нужно переопределить дефолтное логирование,
то в файле конфигов `logging.php` нужно создать таргеты с именами `localization_client` или `localization_update`:

    ...
    'channels' => [
        ...
        'localization_client' => [
            'driver' => 'daily',
            'path' => storage_path('logs/new-path/for-file.log'),
            'level' => 'debug',
            'days' => 14,
            'permission' => 0777
        ],
        'localization_update' => [
            'driver' => 'daily',
            'path' => storage_path('logs/new-path/for-file.log'),
            'level' => 'debug',
            'days' => 14,
            'permission' => 0777
        ],
    ]

# CLI

Для ручного запуска обновления переводов нужно выполнить консольную команду.
Внутри контейнера:

    ./artisan localization:update

Снаружи:

    make artis q=localization:update

Для запуска обновлений по крону в метод `\App\Console\Kernel::schedule` нужно добавить

    $schedule
        ->command(Iwaydev\Localization\Console\UpdateCommand::class)
        ->runInBackground()
        ->withoutOverlapping()
        ->everyTwoMinutes();

# Применение

Для того чтобы получить перевод по метке и языку нужно вызвать метод `\Iwaydev\Localization\Services\LocalizationService::t`

    $status = \Iwaydev\Localization\Services\LocalizationService::t('bizontrip.trip.status.0', 'en')

так же можно использовать хэлпер `translate()`

    $status = translate('bizontrip.trip.status.0')