<?php

namespace Iwaydev\Localization;

use \DomainException;
use Iwaydev\BaseSender\Sender;
use JsonException;
use Psr\Http\Message\ResponseInterface;

/**
 * Class LocalizationClient
 *
 * @package Iwaydev\Localization
 */
class LocalizationClient extends Sender
{
    /**
     * Авторизация
     *
     * @param string $token Токен авторизации
     *
     * @return $this
     */
    public function auth(string $token): self
    {
        $this->setHeader('Authorization', 'Bearer ' . $token);

        return $this;
    }

    /**
     * Аутентификация
     *
     * @param string $login
     * @param string $password
     *
     * @return string
     * @throws JsonException
     */
    public function login(string $login, string $password): string
    {
        $response = $this->post('users/auth/auth', [
            'login' => $login,
            'password' => $password,
        ]);

        return $response['token'];
    }

    /**
     * Возвращает переводы для указанного проекта
     *
     * @param string $projectName
     * @param int $page
     * @param int $limit
     *
     * @return array
     * @throws JsonException
     */
    public function getLocalizations(string $projectName, int $page = 0, int $limit = 1000): array
    {
        return $this->get('localizations', [
            'project_name' => $projectName,
            'limit' => $limit,
            'page' => $page
        ]);
    }

    /**
     * Проверить актуальность меток проекта по хэшу
     *
     * @param string $projectName
     * @param string $currentHash
     *
     * @return array
     * @throws JsonException
     */
    public function checkStatusProject(string $projectName, string $currentHash = ''): array
    {
        return $this->post('localizations/check-status-project', [
            'project_name' => $projectName,
            'hash' => $currentHash,
        ]);
    }

    /**
     * @inheritDoc
     */
    protected function prepareResponse(ResponseInterface $response): array
    {
        $responseData = parent::prepareResponse($response);

        if (isset($responseData['result'])) {
            return $responseData['result'];
        }

        $message = reset($responseData['error']);
        $message = is_array($message) ? $message : $responseData['error'];
        $message = $message['message'] ?? implode(' ', $message);

        throw new DomainException($message);
    }
}
