<?php

namespace Iwaydev\Localization;

use Illuminate\Support\ServiceProvider;
use Iwaydev\Localization\Services\LocalizationService;
use JsonException;
use Throwable;

/**
 * Провайдер сервиса переводов
 *
 * @package Iwaydev\Localization,
 */
class LocalizationServiceProvider extends ServiceProvider
{
    /**
     * Register services.
     *
     * @return void
     */
    public function register(): void
    {
        parent::register();

        $this->setDefaultLogChannel();

        $this->registerSender();
    }

    /**
     * Добавляет в конфиг канал для логирования, если отсутствует
     */
    protected function setDefaultLogChannel(): void
    {
        if (!config()->has('logging.channels.localization_client')) {
            config()->set('logging.channels.localization_client', require __DIR__ . '/../config/log-client.php');
        }
        if (!config()->has('logging.channels.localization_update')) {
            config()->set('logging.channels.localization_update', require __DIR__ . '/../config/log-update.php');
        }
    }

    /**
     * @throws JsonException
     * @throws Throwable
     */
    protected function registerSender(): void
    {
        $this->app->bind(LocalizationClient::class, function ($app) {
            return new LocalizationClient(
                config('senders.localization.connection.url'),
                config('senders.localization.connection.api_version'),
                cache()->store(),
                config('senders.localization.cache.client.lifetime'),
                logs('localization_client'),
                $app->request->header('X-UUID', null)
            );
        });
        $this->app->bind(LocalizationService::class, function ($app) {
            return new LocalizationService(
                resolve(LocalizationClient::class),
                config('senders.localization.connection.project_slug'),
                config('senders.localization.connection.password'),
                logs('localization_update'),
                cache()->store(),
                config('senders.localization.cache.service.lifetime')
            );
        });

        $this->loadHelpers();
    }

    /**
     * Bootstrap services.
     *
     * @return void
     */
    public function boot(): void
    {
        if ($this->app->runningInConsole()) {
            $this->publishes([
                __DIR__ . '/../config/localization.php' => config_path('senders/localization.php'),
            ], 'config');

            $this->publishes([
                __DIR__ . '/LocalizationServiceProvider.php' => app_path('Providers/LocalizationServiceProvider.php'),
            ], 'provider');

            $this->commands([
                Console\UpdateCommand::class,
            ]);
        }
    }

    /**
     * Подгружаем хэлперы
     */
    protected function loadHelpers()
    {
        foreach (glob(__DIR__ . '/Helpers/*.php') as $filename) {
            require_once $filename;
        }
    }
}
